Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: third_party/WebKit/Source/core/frame/FrameSerializer.h

Issue 1541463002: Rename [Web]PageSerializer[Test|Client|Impl] to ...FrameSerializer... (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@mhtml-deduplication-of-resources
Patch Set: Rebasing... Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/core.gypi ('k') | third_party/WebKit/Source/core/frame/FrameSerializer.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/frame/FrameSerializer.h
diff --git a/third_party/WebKit/Source/core/page/PageSerializer.h b/third_party/WebKit/Source/core/frame/FrameSerializer.h
similarity index 94%
rename from third_party/WebKit/Source/core/page/PageSerializer.h
rename to third_party/WebKit/Source/core/frame/FrameSerializer.h
index 0de4675913c9d022dc5082674a279c3aaad55aa6..0c63b68759bbec873845097959af7c4457d2e5a7 100644
--- a/third_party/WebKit/Source/core/page/PageSerializer.h
+++ b/third_party/WebKit/Source/core/frame/FrameSerializer.h
@@ -28,8 +28,8 @@
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef PageSerializer_h
-#define PageSerializer_h
+#ifndef FrameSerializer_h
+#define FrameSerializer_h
#include "core/CoreExport.h"
#include "platform/heap/Handle.h"
@@ -52,7 +52,6 @@ class FontResource;
class ImageResource;
class LocalFrame;
class Node;
-class Page;
class LayoutObject;
class Resource;
class SharedBuffer;
@@ -62,8 +61,7 @@ struct SerializedResource;
// This class is used to serialize frame's contents back to text (typically HTML).
// It serializes frame's document and resources such as images and CSS stylesheets.
-// TODO(lukasza): Rename this class to FrameSerializer.
-class CORE_EXPORT PageSerializer final {
+class CORE_EXPORT FrameSerializer final {
STACK_ALLOCATED();
public:
class Delegate {
@@ -99,8 +97,8 @@ public:
// Constructs a serializer that will write output to the given vector of
// SerializedResources and uses the Delegate for controlling some
// serialization aspects. Callers need to ensure that both arguments stay
- // alive until the PageSerializer gets destroyed.
- PageSerializer(Vector<SerializedResource>&, Delegate&);
+ // alive until the FrameSerializer gets destroyed.
+ FrameSerializer(Vector<SerializedResource>&, Delegate&);
// Initiates the serialization of the frame. All serialized content and
// retrieved resources are added to the Vector passed to the constructor.
@@ -135,4 +133,4 @@ private:
} // namespace blink
-#endif // PageSerializer_h
+#endif // FrameSerializer_h
« no previous file with comments | « third_party/WebKit/Source/core/core.gypi ('k') | third_party/WebKit/Source/core/frame/FrameSerializer.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698